@@ -70,27 +70,31 @@ class ClientLoop(object):
 
     def run_once(self):
         for dir in self.dir_list:
-            if not os.path.exists(dir):
-                os.makedirs(dir)
-                click.echo("create dir {}".format(dir))
-            self.try_delete(dir)
-            j = self.read_serve_list(dir)
-            client_d = self.read_client_md5_value(dir)
-            # 遍历所有的名字,检查需不需要下载,然后下载就好了
-            count = 0
-            for name, md5_value in j.items():
-                if name not in client_d:
-                    count +=1
-                    self.download(name, client_d, dir)
-                    continue
-                if client_d[name] != md5_value:
-                    count +=1
-                    self.download(name, client_d, dir)
-            click.echo("[{}],download file count: {}".format(dir, count))
-            click.echo("="*80)
-            click.echo("[{}] complete".format(dir))
-            click.echo("="*80)
-            self.read_client_md5_value(dir)
+            try:
+                if not os.path.exists(dir):
+                    os.makedirs(dir)
+                    click.echo("create dir {}".format(dir))
+                self.try_delete(dir)
+                j = self.read_serve_list(dir)
+                client_d = self.read_client_md5_value(dir)
+                # 遍历所有的名字,检查需不需要下载,然后下载就好了
+                count = 0
+                for name, md5_value in j.items():
+                    if name not in client_d:
+                        count +=1
+                        self.download(name, client_d, dir)
+                        continue
+                    if client_d[name] != md5_value:
+                        count +=1
+                        self.download(name, client_d, dir)
+                click.echo("[{}],download file count: {}".format(dir, count))
+                click.echo("="*80)
+                click.echo("[{}] complete".format(dir))
+                click.echo("="*80)
+                self.read_client_md5_value(dir)
+            except Exception as e:
+                click.echo("fail to download for dir [{}]".format(dir))
+            
     
     def download(self, name,d, dir):
         prefix = "dir:[{}]".format(dir)
